# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ssl_simulation_robot_control.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ssl_simulation_robot_control.proto',
  package='',
  syntax='proto2',
  serialized_options=b'Z6github.com/RoboCup-SSL/ssl-simulation-protocol/pkg/sim',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"ssl_simulation_robot_control.proto\"\x86\x01\n\x0cRobotCommand\x12\n\n\x02id\x18\x01 \x02(\r\x12\'\n\x0cmove_command\x18\x02 \x01(\x0b\x32\x11.RobotMoveCommand\x12\x12\n\nkick_speed\x18\x03 \x01(\x02\x12\x15\n\nkick_angle\x18\x04 \x01(\x02:\x01\x30\x12\x16\n\x0e\x64ribbler_speed\x18\x05 \x01(\x02\"\xa9\x01\n\x10RobotMoveCommand\x12,\n\x0ewheel_velocity\x18\x01 \x01(\x0b\x32\x12.MoveWheelVelocityH\x00\x12,\n\x0elocal_velocity\x18\x02 \x01(\x0b\x32\x12.MoveLocalVelocityH\x00\x12.\n\x0fglobal_velocity\x18\x03 \x01(\x0b\x32\x13.MoveGlobalVelocityH\x00\x42\t\n\x07\x63ommand\"c\n\x11MoveWheelVelocity\x12\x13\n\x0b\x66ront_right\x18\x01 \x02(\x02\x12\x12\n\nback_right\x18\x02 \x02(\x02\x12\x11\n\tback_left\x18\x03 \x02(\x02\x12\x12\n\nfront_left\x18\x04 \x02(\x02\"C\n\x11MoveLocalVelocity\x12\x0f\n\x07\x66orward\x18\x01 \x02(\x02\x12\x0c\n\x04left\x18\x02 \x02(\x02\x12\x0f\n\x07\x61ngular\x18\x03 \x02(\x02\";\n\x12MoveGlobalVelocity\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\x0f\n\x07\x61ngular\x18\x03 \x02(\x02\"5\n\x0cRobotControl\x12%\n\x0erobot_commands\x18\x01 \x03(\x0b\x32\r.RobotCommandB8Z6github.com/RoboCup-SSL/ssl-simulation-protocol/pkg/sim'
)




_ROBOTCOMMAND = _descriptor.Descriptor(
  name='RobotCommand',
  full_name='RobotCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='RobotCommand.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='move_command', full_name='RobotCommand.move_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kick_speed', full_name='RobotCommand.kick_speed', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kick_angle', full_name='RobotCommand.kick_angle', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dribbler_speed', full_name='RobotCommand.dribbler_speed', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=173,
)


_ROBOTMOVECOMMAND = _descriptor.Descriptor(
  name='RobotMoveCommand',
  full_name='RobotMoveCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wheel_velocity', full_name='RobotMoveCommand.wheel_velocity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_velocity', full_name='RobotMoveCommand.local_velocity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_velocity', full_name='RobotMoveCommand.global_velocity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='RobotMoveCommand.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=176,
  serialized_end=345,
)


_MOVEWHEELVELOCITY = _descriptor.Descriptor(
  name='MoveWheelVelocity',
  full_name='MoveWheelVelocity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='front_right', full_name='MoveWheelVelocity.front_right', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='back_right', full_name='MoveWheelVelocity.back_right', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='back_left', full_name='MoveWheelVelocity.back_left', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_left', full_name='MoveWheelVelocity.front_left', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=446,
)


_MOVELOCALVELOCITY = _descriptor.Descriptor(
  name='MoveLocalVelocity',
  full_name='MoveLocalVelocity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='forward', full_name='MoveLocalVelocity.forward', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left', full_name='MoveLocalVelocity.left', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular', full_name='MoveLocalVelocity.angular', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=515,
)


_MOVEGLOBALVELOCITY = _descriptor.Descriptor(
  name='MoveGlobalVelocity',
  full_name='MoveGlobalVelocity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='MoveGlobalVelocity.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='MoveGlobalVelocity.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular', full_name='MoveGlobalVelocity.angular', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=576,
)


_ROBOTCONTROL = _descriptor.Descriptor(
  name='RobotControl',
  full_name='RobotControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='robot_commands', full_name='RobotControl.robot_commands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=631,
)

_ROBOTCOMMAND.fields_by_name['move_command'].message_type = _ROBOTMOVECOMMAND
_ROBOTMOVECOMMAND.fields_by_name['wheel_velocity'].message_type = _MOVEWHEELVELOCITY
_ROBOTMOVECOMMAND.fields_by_name['local_velocity'].message_type = _MOVELOCALVELOCITY
_ROBOTMOVECOMMAND.fields_by_name['global_velocity'].message_type = _MOVEGLOBALVELOCITY
_ROBOTMOVECOMMAND.oneofs_by_name['command'].fields.append(
  _ROBOTMOVECOMMAND.fields_by_name['wheel_velocity'])
_ROBOTMOVECOMMAND.fields_by_name['wheel_velocity'].containing_oneof = _ROBOTMOVECOMMAND.oneofs_by_name['command']
_ROBOTMOVECOMMAND.oneofs_by_name['command'].fields.append(
  _ROBOTMOVECOMMAND.fields_by_name['local_velocity'])
_ROBOTMOVECOMMAND.fields_by_name['local_velocity'].containing_oneof = _ROBOTMOVECOMMAND.oneofs_by_name['command']
_ROBOTMOVECOMMAND.oneofs_by_name['command'].fields.append(
  _ROBOTMOVECOMMAND.fields_by_name['global_velocity'])
_ROBOTMOVECOMMAND.fields_by_name['global_velocity'].containing_oneof = _ROBOTMOVECOMMAND.oneofs_by_name['command']
_ROBOTCONTROL.fields_by_name['robot_commands'].message_type = _ROBOTCOMMAND
DESCRIPTOR.message_types_by_name['RobotCommand'] = _ROBOTCOMMAND
DESCRIPTOR.message_types_by_name['RobotMoveCommand'] = _ROBOTMOVECOMMAND
DESCRIPTOR.message_types_by_name['MoveWheelVelocity'] = _MOVEWHEELVELOCITY
DESCRIPTOR.message_types_by_name['MoveLocalVelocity'] = _MOVELOCALVELOCITY
DESCRIPTOR.message_types_by_name['MoveGlobalVelocity'] = _MOVEGLOBALVELOCITY
DESCRIPTOR.message_types_by_name['RobotControl'] = _ROBOTCONTROL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RobotCommand = _reflection.GeneratedProtocolMessageType('RobotCommand', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTCOMMAND,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:RobotCommand)
  })
_sym_db.RegisterMessage(RobotCommand)

RobotMoveCommand = _reflection.GeneratedProtocolMessageType('RobotMoveCommand', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTMOVECOMMAND,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:RobotMoveCommand)
  })
_sym_db.RegisterMessage(RobotMoveCommand)

MoveWheelVelocity = _reflection.GeneratedProtocolMessageType('MoveWheelVelocity', (_message.Message,), {
  'DESCRIPTOR' : _MOVEWHEELVELOCITY,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:MoveWheelVelocity)
  })
_sym_db.RegisterMessage(MoveWheelVelocity)

MoveLocalVelocity = _reflection.GeneratedProtocolMessageType('MoveLocalVelocity', (_message.Message,), {
  'DESCRIPTOR' : _MOVELOCALVELOCITY,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:MoveLocalVelocity)
  })
_sym_db.RegisterMessage(MoveLocalVelocity)

MoveGlobalVelocity = _reflection.GeneratedProtocolMessageType('MoveGlobalVelocity', (_message.Message,), {
  'DESCRIPTOR' : _MOVEGLOBALVELOCITY,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:MoveGlobalVelocity)
  })
_sym_db.RegisterMessage(MoveGlobalVelocity)

RobotControl = _reflection.GeneratedProtocolMessageType('RobotControl', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTCONTROL,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:RobotControl)
  })
_sym_db.RegisterMessage(RobotControl)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
